/******************************************************************************
;	SPRING CONTROL PROGRAM FOR ESSGIAS                                        * 	
;                                                                             *     
;                                                                             *
;******************************************************************************
;                                                                             *
;    Filename: 		SPRING_CONTROL_1_0                                        *
;    First Date:  	6.SEPTEMBER 2021										  *
;    Date V1.00:  	16.NOVEMBER 2021										  *
;	 Last Date:		1.JANUARY 2022	                                          *
;    File Version: 	V 1.00                                   				  *
;    PIC18F46K80                                                              *
;    Author: Tom Chaloupek                                                  *
;    Company: ELITRONIC s.r.o.                                                *
;                                                                             * 
;******************************************************************************
;                                                                             *
;    Files required:       htc.h,math.h                                       *
;                                                                             *
;******************************************************************************/
/******************************************************************************/

#include <htc.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

/******************************************************************************/
// konfiguran bity



#pragma config XINST    = OFF
#pragma config CANMX    = PORTB
#pragma config SOSCSEL  = DIG        // pro sprvnou funkci RC0 a RC1 jako I/O
#pragma config FOSC     = INTIO2     //intern hodiny bez vstupu na pin

#pragma config WDTEN    = SWDTDIS   //SWDTDIS - WDT d hardware
#pragma config WDTPS    = 128       //cca 1 sekundy

//#pragma config FOSC     = HS1      //krystal





//data pro eepromku - tovrn nastaven - zape se pi programovn
__EEPROM_DATA(60,50,4,1,1,1,10,40);	//TOV=60,TUV=50,REF=22,P1=1,P2=0,...P5



/******************************************************************************/
// ALIASY
/******************************************************************************/

#define ON					1
#define OFF					0
#define YES					1
#define NO					0
#define ACTIVE				1
#define INACTIVE			0

#define LEFT                0
#define RIGHT               1




#define	LED                 LATCbits.LATC0


#define	PWM2_OUTPUT         LATCbits.LATC2 
#define	PWM5_OUTPUT         LATBbits.LATB5

#define	CMP1                LATDbits.LATD0
#define	CMP2                LATDbits.LATD1

#define V1_1                LATEbits.LATE2
#define V1_2                LATEbits.LATE1
#define V2_1                LATEbits.LATE0
#define V2_2                LATAbits.LATA5

#define	SW_PLUS             PORTDbits.RD4 
#define	SW_MINUS            PORTDbits.RD6 
#define	SW_FUNCTION         PORTDbits.RD5 
#define	SW_ENTER            PORTDbits.RD7 

#define ENCODE_CLK          PORTBbits.RB3
#define ENCODE_DAT          PORTBbits.RB4

/* definice vstup AD pevodnku */
#define	AIN0                0b00000000 /* RA0 */
#define	AIN1                0b00000100 /* RA1 */

// ACC
#define LIS2DW12_ADR        0x32

#define LIS2DW12_2G			0x00
#define LIS2DW12_4G			0x10
#define LIS2DW12_8G			0x20
#define LIS2DW12_16G		0x30

#define BOT_PRESS_MIN		10
#define BOT_PRESS_MAX		100

/******************************************************************************/
/* GLOBLN PROMNN  											  		      */
/******************************************************************************/
unsigned int    CNT_1S;
unsigned int    CNT_DELAY;
unsigned int    DELAY;
unsigned int    CNT_GENERAL;
unsigned int    ACC_DISP_CNT;
unsigned int    MOTOR_RAMP_CNT;
unsigned int    VENTIL_DELAY;

unsigned char   ind = 0x78; //0078

unsigned char   SERIAL_BUFFER_1[100];
unsigned char   I2C_BUFFER_1[10];
unsigned char   ACC_X_STR[20];
unsigned char   ACC_Y_STR[20];
unsigned char   ACC_Z_STR[20];
unsigned char   ACC_T_STR[20];
unsigned char   ACC_H_STR[20];
unsigned char   PRESS_STR[5];
unsigned char   INT_PTR_1;

unsigned char   DISPLAY [1024];
unsigned char   ZNAKY [100];
unsigned char   TEMPR[20];
unsigned char   TEPLOTA;

unsigned int    PWM_DUTY_FULL;
unsigned char   PWM_LB;
unsigned char   PWM_MB;

unsigned char   PWM_COMP1;
unsigned char   PWM_COMP2;
unsigned char   DUTY_COMP1;
unsigned char   DUTY_COMP2;


unsigned char   ENCODER_VALUE;

unsigned char   j;
unsigned char   i;
unsigned char   RESULT;

unsigned int    PRESS_1;
unsigned int    PRESS_2;
unsigned char   PRESS_1_KPA;
unsigned char   PRESS_2_KPA;
unsigned char   PRESS_IN_BOTTLE;
unsigned char   PRESS_HYSTERESE;


unsigned char   ACC_RANGE;
int             ACC_X;
int             ACC_Y;
int             ACC_Z;

float           ACC_X_MG;
float           ACC_Y_MG;
float           ACC_Z_MG;
float           DIVIDER;

int             GYR_X;
int             GYR_Y;
int             GYR_Z;

int             TEMPERATURE;
unsigned char   GENERAL_DATA;

float           TEMP_FL;
float           TEMP_FL_ABS;
float           TEMP_DEC;
const float     A=1.953125e-03;
const float     B=0.125;

const float     T=0.0039215686;

unsigned int    GPD1;
unsigned int    GPD2;
unsigned int    DOT_POS;


const float     K=0.97751711;

float           PRESS_FLOAT;
const float     PRS=40.95;

//bitov promnn
bit DIRECTION;
bit GP1;
bit PRESS_IN_PROGRES;
bit KOMPRESOR_RUN;
bit KOMPR_HIGH;
bit PROCES_START;



/******************************************************************************/
/* PROCEDURY A FUNKCE  											  		      */
/******************************************************************************/
/******************************************************************************/
/* peruen vy priorita 	od TMR0 a od RS232-2 						  */
/******************************************************************************/
void __interrupt(high_priority) ISR(void)
{
    
	// peruen od tae 0 - po 0.01 sec
	if (TMR0IF == ON)
	{
		// DOBA CITANI 
		TMR0H=0xC1;		//63C0, F05F=0.001s 16Mhz,
		TMR0L=0x7F;

        ++CNT_1S;
        ++DELAY;
        ++CNT_DELAY;
        ++CNT_GENERAL;
        ++ACC_DISP_CNT;
        ++MOTOR_RAMP_CNT;
        
        
        if(CNT_1S == 1000)            
        {    
            LED = !LED;
            CNT_1S = 0;
            
            ++VENTIL_DELAY;
            if (VENTIL_DELAY == 200) VENTIL_DELAY = 199;
        } 
                               
		TMR0IF = OFF; //znovupovolen interuptu od tae 0
        return;
     }
        
        
     //encoder interrupt
     if(INTCON3bits.INT3IF == ON)
     {
         
        GP1 = ENCODE_CLK;

        
        if(ENCODE_DAT == ON)
        {
           /* DIRECTION = LEFT; //ODT
            --ENCODER_VALUE;
            PWM_DUTY_FULL = PWM_DUTY_FULL - 5;
            if (PWM_DUTY_FULL > 1023) PWM_DUTY_FULL = 0;
             */
            
           /* --DUTY_COMP1;
            --DUTY_COMP2;
            if (DUTY_COMP1 == 0xFF) DUTY_COMP1 = 0; 
            if (DUTY_COMP2 == 0xFF) DUTY_COMP2 = 0; 
           */
            
            --PRESS_IN_BOTTLE;
            if (PRESS_IN_BOTTLE < BOT_PRESS_MIN) PRESS_IN_BOTTLE = BOT_PRESS_MIN;
        }    
        
        if(ENCODE_DAT == OFF)
        {
           /* DIRECTION = RIGHT;  //PIT
            ++ENCODER_VALUE;
            PWM_DUTY_FULL = PWM_DUTY_FULL + 5;
            if (PWM_DUTY_FULL > 1023) PWM_DUTY_FULL = 1023;
            */
            
           /* ++DUTY_COMP1;
            ++DUTY_COMP2;
            if (DUTY_COMP1 == 101) DUTY_COMP1 = 100;     
            if (DUTY_COMP2 == 101) DUTY_COMP2 = 100;     
           */
            
            ++PRESS_IN_BOTTLE;
            if (PRESS_IN_BOTTLE > BOT_PRESS_MAX) PRESS_IN_BOTTLE = BOT_PRESS_MAX;
        }    
                            
        INTCON3bits.INT3IF = OFF;    
     }    
    	
}

/******************************************************************************/
/* peruen ni priorita 	od TMR0 a od RS232-2 						  */
/******************************************************************************/
void __interrupt(low_priority) ISRLP(void)
{
    
	
	// peruen od RS232-usart 2
	if (RC1IF == ON)
	{
        
        SERIAL_BUFFER_1[INT_PTR_1++] = RCREG1;
               
        
        if (INT_PTR_1 == 99) 
        {
            INT_PTR_1 = 0;
        }   
	}
    
    
    //peruen od TMR1
    if (TMR1IF == ON)
    {
        TMR1    = 0xF900;//f100
        
        ++PWM_COMP1;
        ++PWM_COMP2;
        
        //PWM na COMP1 a COMP2
        if (PWM_COMP1 == DUTY_COMP1)
        {
            if (DUTY_COMP1 == 100) CMP1 = ON;                
            else CMP1 = OFF;
        }
        if (PWM_COMP1 == 100)
        {
            if (DUTY_COMP1 == 0) CMP1 = OFF;  
            else CMP1 = ON;
            PWM_COMP1  = 0;
        }    
        
        //a druhej
        if (PWM_COMP2 == DUTY_COMP2)
        {
            if (DUTY_COMP2 == 100) CMP2 = ON;                
            else CMP2 = OFF;
        }
        if (PWM_COMP2 == 100)
        {
            if (DUTY_COMP2 == 0) CMP2 = OFF;  
            else CMP2 = ON;
            PWM_COMP2  = 0;
        }    
        
        
       
        TMR1IF = OFF;
    }    
    
}
/******************************************************************************/
/* INICIALIZACE PROCESORU  													  */
/******************************************************************************/
void InitPeripherals(void) 
{
        
    // Set the internal oscillator
    OSCCONbits.IRCF   = 7; // 16MHz  
    OSCTUNEbits.PLLEN = 1; //1-povol PLLx4, 0-zake
    
    
    
    /*nastaven A/D pevodnku*/			
	ADCON0 = 0B00000001;		
	ADCON1 = 0B00100000;	/* ref 2.0V a GND*/
	ADCON2 = 0B10001110;    //xxxxx101	@20MHz 110 @64MHz
    
 
    PSPMODE = 0;
   
    // nastaven port
    PORTA   = 0;
	TRISA   = 0B11011111;
    
    RBPU  = 0; // zapne pull up = 1
    PORTB = 0;
	TRISB = 0B11011011; //tlatko na EXPLORER 18 RB0, CCP5 OUTPUT
    WPUBbits.WPUB3 = 1; //individualn polvolen PULL UP
    WPUBbits.WPUB4 = 1;
    
    PORTC = 0;
	TRISC = 0B10111010;
    
    PORTD = 0;
	TRISD = 0B11111100; //ledky na EXPLORER 18
    
    PORTE = 0;
	TRISE = 0B11111000;
    
  
       
    ANCON0 = 0b00000011; //analog=1, digital=0
    ANCON1 = 0b00000000;
    

  
    //globln peruen
    
    
    INTCONbits.GIE_GIEH  = 1; //global
    INTCONbits.PEIE_GIEL = 1; //periferie
    
    //PERUEN NA PORTU B
    INTCON3bits.INT3IE  = ON; //povol INT3
    INTCON2bits.INT3IP  = ON; //vy priorita
    INTCON2bits.INTEDG3 = OFF; //sestupn hrana

    
    
    /* INICIALIZACE SSPM jako I2C */
	SSPSTAT = 0b10000000;
	SSPCON1 = 0b00101000; 	//nastaven pro MASTER mode
	SSPCON2 = 0b00000000; 	//nastaven pro MASTER mode
	SSPADD  = 0b00100110;	//rychlost hodin na I2C 1F=156 kHz, 09=400 kHz-@16Mhz 0x26=400 kHz-@64Mhz
    
    
    
    
	/* NASTAVEN TAE-0 A JEHO PERUEN */
	T0CON 	= 0B10001000;	// PRESCALER nen	
	TMR0IE 	= 1;            // povol peruen od tae 0
	TMR0IP 	= 1;            // Vy rove peruen 1
	TMR0H	= 0x3C;         // inicializacni hodnota 0.01s		
	TMR0L	= 0xAF;
    TMR0IE  = ON;
    
    
    
	// POVOLI PRERUSENI A PRIORITU
	IPEN    = 1;			// povol PRIORITU peruen vy 1
	GIEH    = 1;			// POVOLI INT GLOBAL
	GIEL    = 1;			// POVOLI INT PERIFERIE
 
    
    
    
    // NASTAVEN PWM NA CCP2
    PR2		= 0xFF; //frekvence pwm
	T2CKPS0 = 0;//prescaler 00=1, 01=4, 10=16 frekvence pwm
	T2CKPS1 = 1;
    CCPTMRSbits.C2TSEL = 0; //TMR2
	CCPR2L  = 0x7F; //duty cycle 0-255 = 0-99%
	CCP2CON = 0B00001100; //ECCP - single out P1A,P1A active high
	TMR2	= 0x00;
    
	TMR2ON	= INACTIVE;
    
  
    // NASTAVEN PWM NA CCP5
    PR4		= 0xFF; //frekvence pwm
	T4CKPS0 = 0;//prescaler 00=1, 01=4, 10=16 frekvence pwm
	T4CKPS1 = 1;
    CCPTMRSbits.C5TSEL = 1; //TMR4
	CCPR5L  = 0x7F; //duty cycle 0-255 = 0-99%
	CCP5CON = 0B00001100; //ECCP - single out P1A,P1A active high
	TMR4	= 0x00;    
    
	TMR4ON	= INACTIVE;
    
    
    //Nastaven TIMER1
    T1CON   = 0B01001010;
    T1GCON  = 0B00000000;
    TMR1IE  = ON;   //povol peruen
    TMR1IP  = 0;    // 0-ni, 1 vy
    
    TMR1    = 0xFF00;
            
    TMR1ON  = ACTIVE;         
    

}


/******************************************************************************/
/* INICIALIZACE USART 2 PRO KOMUNIKACI                        			      */
/******************************************************************************/

void Init_RS232_1(unsigned int BDS)

{
	
	RCSTA1      = 0b10010000; 	//Serial Enebled,8bit,pjem povolen
	BAUDCON1    = 0b00001000;	// BRG16=1
	TXSTA1      = 0b00100100;	// BRGH=1


	if (BDS == 11520)
	{
            SPBRGH1	= 0x00;			// 115200 bd pi @16Mhz
            SPBRG1  = 0x21;
	}

	if (BDS == 57600)
	{
            SPBRGH1	= 0x00;			// 57600 bd pi @16Mhz
            SPBRG1  = 0x45;
	}
	if (BDS == 38400)
	{
            SPBRGH1	= 0x00;			// 38400 bd pi @16Mhz
            SPBRG1  = 0x68;
	}
	if (BDS == 19200)
	{
            SPBRGH1 = 0x00;			// 19200 bd pi @16Mhz
            SPBRG1  = 0xD0;
	}
	if (BDS == 9600)
	{
            SPBRGH1	= 0x01;			// 9600 bd pi @16Mhz
            SPBRG1  = 0xA0;
	}
	if (BDS == 4800)
	{
            SPBRGH1	= 0x03;			// 4800 bd pi @16Mhz
            SPBRG1  = 0x41;
	}
	if (BDS == 2400)
	{
            SPBRGH1	= 0x06;			// 2400 bd pi @16Mhz
            SPBRG1  = 0x82;
	}
	if (BDS == 1200)
	{
            SPBRGH1	= 0x0D;			// 1200 bd pi @16Mhz
            SPBRG1  = 0x05;
	}

	/* peruen od pchozho znaku */
	RC1IE	= ACTIVE;
	RC1IP	= INACTIVE;                       //ni rove peruen
}

void Send_Byte_To_USART_1(unsigned char DATA)
{
        TXSTA1bits.TXEN1 = ACTIVE;   
        RCSTA1bits.CREN1 = INACTIVE; //zake pjem bhem vysln
                		            
        TXREG1 = DATA;
        while (TXSTA1bits.TRMT1 == 0)
        {
        }                
        RCSTA1bits.CREN1 = ACTIVE; //povol pjem
        //INT_PTR_1 = 0;   
    
}    

/******************************************************************************/		
/* Pole zprvu na USART1 - RS485 					      */
/******************************************************************************/
void Send_Message_To_USART_2(void)
{

    unsigned char       i;
		
    
		TXSTA1bits.TXEN1 = ACTIVE;   
        RCSTA1bits.CREN1 = INACTIVE; //zake pjem bhem vysln
                
		for (i = 0; i < INT_PTR_1; i++)
		{
            
            TXREG1 = SERIAL_BUFFER_1[i];
            while (TXSTA1bits.TRMT1 == 0)
            {
            }
		}
        
                           
        RCSTA1bits.CREN1 = ACTIVE; //povol pjem
        INT_PTR_1 = 0;
                
}


/******************************************************************************/		
/* obsluha displeje OLED 128x64                                               */
/******************************************************************************/


const char TEXT[51][5] = 
{
    0x00, 0x00, 0x00, 0x00, 0x00,	 // 	(Space)
  	0x00, 0x00, 0x5F, 0x00, 0x00,	 // 	!
  	0x00, 0x07, 0x00, 0x07, 0x00,	 // 	"
  	0x14, 0x7F, 0x14, 0x7F, 0x14,	 // 	#
  	0x24, 0x2A, 0x7F, 0x2A, 0x12,	 // 	$
  	0x23, 0x13, 0x08, 0x64, 0x62,	 // 	%
  	0x36, 0x49, 0x56, 0x20, 0x50,	 // 	&
  	0x00, 0x08, 0x07, 0x03, 0x00,	 // 	'
  	0x00, 0x1C, 0x22, 0x41, 0x00,	 // 	(
  	0x00, 0x41, 0x22, 0x1C, 0x00,	 // 	)
  	0x2A, 0x1C, 0x7F, 0x1C, 0x2A,	 // 	*
  	0x08, 0x08, 0x3E, 0x08, 0x08,	 // 	+
  	0x00, 0x00, 0x70, 0x30, 0x00,	 // 	,
  	0x08, 0x08, 0x08, 0x08, 0x08,	 // 	-
  	0x00, 0x00, 0x60, 0x60, 0x00,	 // 	.
  	0x20, 0x10, 0x08, 0x04, 0x02,	 // 	/
  	0x3E, 0x51, 0x49, 0x45, 0x3E,	 // 	0
  	0x00, 0x42, 0x7F, 0x40, 0x00,	 // 	1
  	0x72, 0x49, 0x49, 0x49, 0x46,	 // 	2
  	0x21, 0x41, 0x49, 0x4D, 0x33,	 // 	3
  	0x18, 0x14, 0x12, 0x7F, 0x10,	 // 	4
  	0x27, 0x45, 0x45, 0x45, 0x39,	 // 	5
  	0x3C, 0x4A, 0x49, 0x49, 0x31,	 // 	6
  	0x41, 0x21, 0x11, 0x09, 0x07,	 // 	7
  	0x36, 0x49, 0x49, 0x49, 0x36,	 // 	8
  	0x46, 0x49, 0x49, 0x29, 0x1E,	 // 	9
  	0x00, 0x00, 0x14, 0x00, 0x00,	 // 	:
  	0x00, 0x40, 0x34, 0x00, 0x00,	 // 	;
  	0x00, 0x08, 0x14, 0x22, 0x41,	 // 	<
  	0x14, 0x14, 0x14, 0x14, 0x14,	 // 	=
  	0x00, 0x41, 0x22, 0x14, 0x08,	 // 	>
  	0x02, 0x01, 0x59, 0x09, 0x06,	 // 	?
  	0x3E, 0x41, 0x5D, 0x59, 0x4E,	 // 	@
  	0x7C, 0x12, 0x11, 0x12, 0x7C,	 // 	A
  	0x7F, 0x49, 0x49, 0x49, 0x36,	 // 	B
  	0x3E, 0x41, 0x41, 0x41, 0x22,	 // 	C
  	0x7F, 0x41, 0x41, 0x41, 0x3E,	 // 	D
  	0x7F, 0x49, 0x49, 0x49, 0x41,	 // 	E
  	0x7F, 0x09, 0x09, 0x09, 0x01,	 // 	F
  	0x3E, 0x41, 0x41, 0x51, 0x73,	 // 	G
  	0x7F, 0x08, 0x08, 0x08, 0x7F,	 // 	H
  	0x00, 0x41, 0x7F, 0x41, 0x00,	 // 	I
  	0x20, 0x40, 0x41, 0x3F, 0x01,	 // 	J
  	0x7F, 0x08, 0x14, 0x22, 0x41,	 // 	K
  	0x7F, 0x40, 0x40, 0x40, 0x40,	 // 	L
  	0x7F, 0x02, 0x1C, 0x02, 0x7F,	 // 	M
  	0x7F, 0x04, 0x08, 0x10, 0x7F,	 // 	N
  	0x3E, 0x41, 0x41, 0x41, 0x3E,	 // 	O
  	0x7F, 0x09, 0x09, 0x09, 0x06,	 // 	P
  	0x3E, 0x41, 0x51, 0x21, 0x5E,	 // 	Q
  	0x7F, 0x09, 0x19, 0x29, 0x46,	 // 	R
};

const char TEXT2[44][5]=
{
  	0x26, 0x49, 0x49, 0x49, 0x32,	 // 	S
  	0x03, 0x01, 0x7F, 0x01, 0x03,	 // 	T
  	0x3F, 0x40, 0x40, 0x40, 0x3F,	 // 	U
  	0x1F, 0x20, 0x40, 0x20, 0x1F,	 // 	V
  	0x3F, 0x40, 0x38, 0x40, 0x3F,	 // 	W
  	0x63, 0x14, 0x08, 0x14, 0x63,	 // 	X
  	0x03, 0x04, 0x78, 0x04, 0x03,	 // 	Y
  	0x61, 0x59, 0x49, 0x4D, 0x43,	 // 	Z
  	0x00, 0x7F, 0x41, 0x41, 0x41,	 // 	[
  	0x02, 0x04, 0x08, 0x10, 0x20,	 // 	"\"
  	0x00, 0x41, 0x41, 0x41, 0x7F,	 // 	]
  	0x04, 0x02, 0x01, 0x02, 0x04,	 // 	^
  	0x40, 0x40, 0x40, 0x40, 0x40,	 // 	_
  	0x00, 0x03, 0x07, 0x08, 0x00,	 // 	`
  	0x20, 0x54, 0x54, 0x38, 0x40,	 // 	a
  	0x7F, 0x28, 0x44, 0x44, 0x38,	 // 	b
  	0x38, 0x44, 0x44, 0x44, 0x28,	 // 	c
  	0x38, 0x44, 0x44, 0x28, 0x7F,	 // 	d
  	0x38, 0x54, 0x54, 0x54, 0x18,	 // 	e
  	0x00, 0x08, 0x7E, 0x09, 0x02,	 // 	f
  	0x0C, 0x52, 0x52, 0x4A, 0x3C,	 // 	g
  	0x7F, 0x08, 0x04, 0x04, 0x78,	 // 	h
  	0x00, 0x44, 0x7D, 0x40, 0x00,	 // 	i
  	0x20, 0x40, 0x40, 0x3D, 0x00,	 // 	j
  	0x7F, 0x10, 0x28, 0x44, 0x00,	 // 	k
  	0x00, 0x41, 0x7F, 0x40, 0x00,	 // 	l
  	0x7C, 0x04, 0x78, 0x04, 0x78,	 // 	m
  	0x7C, 0x08, 0x04, 0x04, 0x78,	 // 	n
  	0x38, 0x44, 0x44, 0x44, 0x38,	 // 	o
  	0x7C, 0x18, 0x24, 0x24, 0x18,	 // 	p
  	0x18, 0x24, 0x24, 0x18, 0x7C,	 // 	q
  	0x7C, 0x08, 0x04, 0x04, 0x08,	 // 	r
  	0x48, 0x54, 0x54, 0x54, 0x24,	 // 	s
  	0x04, 0x04, 0x3F, 0x44, 0x24,	 // 	t
  	0x3C, 0x40, 0x40, 0x20, 0x7C,	 // 	u
  	0x1C, 0x20, 0x40, 0x20, 0x1C,	 // 	v
  	0x3C, 0x40, 0x30, 0x40, 0x3C,	 // 	w
  	0x44, 0x28, 0x10, 0x28, 0x44,	 // 	x
  	0x4C, 0x50, 0x50, 0x50, 0x3C,	 // 	y
  	0x44, 0x64, 0x54, 0x4C, 0x44,	 // 	z
  	0x00, 0x08, 0x36, 0x41, 0x00,	 // 	{
  	0x00, 0x00, 0x77, 0x00, 0x00,	 // 	|
  	0x00, 0x41, 0x36, 0x08, 0x00,	 // 	}
  	0x02, 0x01, 0x02, 0x04, 0x02,	 // 	~
};


/*
const char TEXT[51][5] =
{

   0x00, 0x00, 0x00, 0x00, 0x00, // SPACE
   0x00, 0x00, 0x5F, 0x00, 0x00, // !
   0x00, 0x03, 0x00, 0x03, 0x00, // "
   0x14, 0x3E, 0x14, 0x3E, 0x14, // #
   0x24, 0x2A, 0x7F, 0x2A, 0x12, // $
   0x43, 0x33, 0x08, 0x66, 0x61, // %
   0x36, 0x49, 0x55, 0x22, 0x50, // &
   0x00, 0x05, 0x03, 0x00, 0x00, // '
   0x00, 0x1C, 0x22, 0x41, 0x00, // (
   0x00, 0x41, 0x22, 0x1C, 0x00, // )
   0x14, 0x08, 0x3E, 0x08, 0x14, // *
   0x08, 0x08, 0x3E, 0x08, 0x08, // +
   0x00, 0x50, 0x30, 0x00, 0x00, // ,
   0x08, 0x08, 0x08, 0x08, 0x08, // -
   0x00, 0x60, 0x60, 0x00, 0x00, // .
   0x20, 0x10, 0x08, 0x04, 0x02, // /
   0x3E, 0x51, 0x49, 0x45, 0x3E, // 0
   0x04, 0x02, 0x7F, 0x00, 0x00, // 1
   0x42, 0x61, 0x51, 0x49, 0x46, // 2
   0x22, 0x41, 0x49, 0x49, 0x36, // 3
   0x18, 0x14, 0x12, 0x7F, 0x10, // 4
   0x27, 0x45, 0x45, 0x45, 0x39, // 5
   0x3E, 0x49, 0x49, 0x49, 0x32, // 6
   0x01, 0x01, 0x71, 0x09, 0x07, // 7
   0x36, 0x49, 0x49, 0x49, 0x36, // 8
   0x26, 0x49, 0x49, 0x49, 0x3E, // 9
   0x00, 0x36, 0x36, 0x00, 0x00, // :
   0x00, 0x56, 0x36, 0x00, 0x00, // ;
   0x08, 0x14, 0x22, 0x41, 0x00, // <
   0x14, 0x14, 0x14, 0x14, 0x14, // =
   0x00, 0x41, 0x22, 0x14, 0x08, // >
   0x02, 0x01, 0x51, 0x09, 0x06, // ?
   0x3E, 0x41, 0x59, 0x55, 0x5E, // @
   0x7E, 0x09, 0x09, 0x09, 0x7E, // A
   0x7F, 0x49, 0x49, 0x49, 0x36, // B
   0x3E, 0x41, 0x41, 0x41, 0x22, // C
   0x7F, 0x41, 0x41, 0x41, 0x3E, // D
   0x7F, 0x49, 0x49, 0x49, 0x41, // E
   0x7F, 0x09, 0x09, 0x09, 0x01, // F
   0x3E, 0x41, 0x41, 0x49, 0x3A, // G
   0x7F, 0x08, 0x08, 0x08, 0x7F, // H
   0x00, 0x41, 0x7F, 0x41, 0x00, // I
   0x30, 0x40, 0x40, 0x40, 0x3F, // J
   0x7F, 0x08, 0x14, 0x22, 0x41, // K
   0x7F, 0x40, 0x40, 0x40, 0x40, // L
   0x7F, 0x02, 0x0C, 0x02, 0x7F, // M
   0x7F, 0x02, 0x04, 0x08, 0x7F, // N
   0x3E, 0x41, 0x41, 0x41, 0x3E, // O
   0x7F, 0x09, 0x09, 0x09, 0x06, // P
   0x1E, 0x21, 0x21, 0x21, 0x5E, // Q
   0x7F, 0x09, 0x09, 0x09, 0x76  // R
}; 

const char TEXT2[44][5]=
{
   0x26, 0x49, 0x49, 0x49, 0x32, // S
   0x01, 0x01, 0x7F, 0x01, 0x01, // T
   0x3F, 0x40, 0x40, 0x40, 0x3F, // U
   0x1F, 0x20, 0x40, 0x20, 0x1F, // V
   0x7F, 0x20, 0x10, 0x20, 0x7F, // W
   0x41, 0x22, 0x1C, 0x22, 0x41, // X
   0x07, 0x08, 0x70, 0x08, 0x07, // Y
   0x61, 0x51, 0x49, 0x45, 0x43, // Z
   0x00, 0x7F, 0x41, 0x00, 0x00, // [
   0x02, 0x04, 0x08, 0x10, 0x20, // 
   0x00, 0x00, 0x41, 0x7F, 0x00, // ]
   0x04, 0x02, 0x01, 0x02, 0x04, // ^
   0x40, 0x40, 0x40, 0x40, 0x40, // _
   0x00, 0x01, 0x02, 0x04, 0x00, // `
   0x20, 0x54, 0x54, 0x54, 0x78, // a
   0x7F, 0x44, 0x44, 0x44, 0x38, // b
   0x38, 0x44, 0x44, 0x44, 0x44, // c
   0x38, 0x44, 0x44, 0x44, 0x7F, // d
   0x38, 0x54, 0x54, 0x54, 0x18, // e
   0x04, 0x04, 0x7E, 0x05, 0x05, // f
   0x08, 0x54, 0x54, 0x54, 0x3C, // g
   0x7F, 0x08, 0x04, 0x04, 0x78, // h
   0x00, 0x44, 0x7D, 0x40, 0x00, // i
   0x20, 0x40, 0x44, 0x3D, 0x00, // j
   0x7F, 0x10, 0x28, 0x44, 0x00, // k
   0x00, 0x41, 0x7F, 0x40, 0x00, // l
   0x7C, 0x04, 0x78, 0x04, 0x78, // m
   0x7C, 0x08, 0x04, 0x04, 0x78, // n
   0x38, 0x44, 0x44, 0x44, 0x38, // o
   0x7C, 0x14, 0x14, 0x14, 0x08, // p
   0x08, 0x14, 0x14, 0x14, 0x7C, // q
   0x00, 0x7C, 0x08, 0x04, 0x04, // r
   0x48, 0x54, 0x54, 0x54, 0x20, // s
   0x04, 0x04, 0x3F, 0x44, 0x44, // t
   0x3C, 0x40, 0x40, 0x20, 0x7C, // u
   0x1C, 0x20, 0x40, 0x20, 0x1C, // v
   0x3C, 0x40, 0x30, 0x40, 0x3C, // w
   0x44, 0x28, 0x10, 0x28, 0x44, // x
   0x0C, 0x50, 0x50, 0x50, 0x3C, // y
   0x44, 0x64, 0x54, 0x4C, 0x44, // z
   0x00, 0x08, 0x36, 0x41, 0x41, // {
   0x00, 0x00, 0x7F, 0x00, 0x00, //|
   0x41, 0x41, 0x36, 0x08, 0x00, // }
   0x02, 0x01, 0x02, 0x04, 0x02  // ~
};
/*

const char TEXT[51][5] =
{
0x00,0x00,0x00,0x00,0x00, // SPACE

  0x00,0x00,0x4F,0x00,0x00, // !
  0x00,0x07,0x00,0x07,0x00, // "
  0x14,0x7F,0x14,0x7F,0x14, // #
  0x24,0x2A,0x7F,0x2A,0x12, // $
  0x23,0x13,0x08,0x64,0x62, // %
  0x36,0x49,0x55,0x22,0x50, // &
  0x00,0x05,0x03,0x00,0x00, // '
  0x00,0x1C,0x22,0x41,0x00, // (
  0x00,0x41,0x22,0x1C,0x00, // )
  0x14,0x08,0x3E,0x08,0x14, // *
  0x08,0x08,0x3E,0x08,0x08, // +
  0x00,0x50,0x30,0x00,0x00, // ,
  0x08,0x08,0x08,0x08,0x08, // -
  0x00,0x60,0x60,0x00,0x00, // .
  0x20,0x10,0x08,0x04,0x02, // /

  0x3E,0x51,0x49,0x45,0x3E, // 0
  0x00,0x42,0x7F,0x40,0x00, // 1
  0x42,0x61,0x51,0x49,0x46, // 2
  0x21,0x41,0x45,0x4B,0x31, // 3
  0x18,0x14,0x12,0x7F,0x10, // 4
  0x27,0x45,0x45,0x45,0x39, // 5
  0x3C,0x4A,0x49,0x49,0x30, // 6
  0x01,0x71,0x09,0x05,0x03, // 7
  0x36,0x49,0x49,0x49,0x36, // 8
  0x06,0x49,0x49,0x29,0x1E, // 9

  0x36,0x36,0x00,0x00,0x00, // :
  0x56,0x36,0x00,0x00,0x00, // ;
  0x08,0x14,0x22,0x41,0x00, // <
  0x14,0x14,0x14,0x14,0x14, // =
  0x00,0x41,0x22,0x14,0x08, // >
  0x02,0x01,0x51,0x09,0x06, // ?
  0x30,0x49,0x79,0x41,0x3E, // @

  0x7E,0x11,0x11,0x11,0x7E, // A
  0x7F,0x49,0x49,0x49,0x36, // B
  0x3E,0x41,0x41,0x41,0x22, // C
  0x7F,0x41,0x41,0x22,0x1C, // D
  0x7F,0x49,0x49,0x49,0x41, // E
  0x7F,0x09,0x09,0x09,0x01, // F
  0x3E,0x41,0x49,0x49,0x7A, // G
  0x7F,0x08,0x08,0x08,0x7F, // H
  0x00,0x41,0x7F,0x41,0x00, // I
  0x20,0x40,0x41,0x3F,0x01, // J
  0x7F,0x08,0x14,0x22,0x41, // K
  0x7F,0x40,0x40,0x40,0x40, // L
  0x7F,0x02,0x0C,0x02,0x7F, // M
  0x7F,0x04,0x08,0x10,0x7F, // N
  0x3E,0x41,0x41,0x41,0x3E, // O
  0x7F,0x09,0x09,0x09,0x06, // P
  0x3E,0x41,0x51,0x21,0x5E, // Q
  0x7F,0x09,0x19,0x29,0x46, // R
 }; 
        
 const char TEXT2[44][5]=
{       
 0x46,0x49,0x49,0x49,0x31, // S
  0x01,0x01,0x7F,0x01,0x01, // T
  0x3F,0x40,0x40,0x40,0x3F, // U
  0x1F,0x20,0x40,0x20,0x1F, // V
  0x3F,0x40,0x30,0x40,0x3F, // W
  0x63,0x14,0x08,0x14,0x63, // X
  0x07,0x08,0x70,0x08,0x07, // Y
  0x61,0x51,0x49,0x45,0x43, // Z

  0x00,0x7F,0x41,0x41,0x00, // [
  0x02,0x04,0x08,0x10,0x20, // backslash
  0x00,0x41,0x41,0x7F,0x00, // ]
  0x04,0x02,0x01,0x02,0x04, // ^
  0x40,0x40,0x40,0x40,0x40, // _
  0x00,0x01,0x02,0x04,0x00, // `

  0x20,0x54,0x54,0x54,0x78, // a
  0x7F,0x50,0x48,0x48,0x30, // b
  0x38,0x44,0x44,0x44,0x20, // c
  0x38,0x44,0x44,0x48,0x7F, // d
  0x38,0x54,0x54,0x54,0x18, // e
  0x08,0x7E,0x09,0x01,0x02, // f
  0x0C,0x52,0x52,0x52,0x3E, // g
  0x7F,0x08,0x04,0x04,0x78, // h
  0x00,0x44,0x7D,0x40,0x00, // i
  0x20,0x40,0x44,0x3D,0x00, // j
  0x7F,0x10,0x28,0x44,0x00, // k
  0x00,0x41,0x7F,0x40,0x00, // l
  0x78,0x04,0x58,0x44,0x78, // m
  0x7C,0x08,0x04,0x04,0x78, // n
  0x38,0x44,0x44,0x44,0x38, // o
  0x7C,0x14,0x14,0x14,0x08, // p
  0x08,0x14,0x14,0x18,0x7C, // q
  0x7C,0x08,0x04,0x04,0x08, // r
  0x48,0x54,0x54,0x54,0x20, // s
  0x04,0x3F,0x44,0x40,0x20, // t
  0x3C,0x40,0x40,0x20,0x7C, // u
  0x1C,0x20,0x40,0x20,0x1C, // v
  0x3C,0x40,0x30,0x40,0x3C, // w
  0x44,0x28,0x10,0x28,0x44, // x
  0x0C,0x50,0x50,0x50,0x3C, // y
  0x44,0x64,0x54,0x4C,0x44, // z

  0x00,0x08,0x36,0x41,0x00, // {
  0x00,0x00,0x7F,0x00,0x00, // |
  0x00,0x41,0x36,0x08,0x00, // }
  0x0C,0x02,0x0C,0x10,0x0C, // ~
   };*/

 
// OBRZEK - BIT MAPA
/*const char spam [1024] =
{
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0xF8, 0xF8, 0x08, 0xF8, 0xF8, 0xF0,
0x00, 0x00, 0xF8, 0xF8, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0x88, 0x88,
0x88, 0x08, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0x18, 0xF8, 0xF0, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x20, 0x30, 0xF8, 0xF8, 0xF8, 0x00, 0x00, 0x00, 0x30,
0x38, 0x38, 0x88, 0xF8, 0xF8, 0x70, 0x00, 0x00, 0x70, 0xF8, 0xF8, 0xC8, 0xF8, 0xF8, 0x70, 0x00,
0x00, 0x60, 0xE0, 0xE0, 0x80, 0xE0, 0xE0, 0x60, 0x00, 0x00, 0xC0, 0xE0, 0xF8, 0x78, 0xD8, 0xC8,
0x80, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xE0, 0xE0, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x0F, 0x0F, 0x08, 0x0F, 0x0F, 0x07,
0x00, 0x00, 0x0F, 0x0F, 0x0F, 0x08, 0x08, 0x08, 0x08, 0x00, 0x00, 0x0F, 0x0F, 0x0F, 0x08, 0x08,
0x08, 0x08, 0x00, 0x00, 0x0F, 0x0F, 0x0F, 0x0C, 0x0F, 0x07, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0x0F, 0x0F, 0x00, 0x80, 0x80, 0x8C,
0x0E, 0x0F, 0x0B, 0x09, 0x08, 0x08, 0x00, 0x00, 0x07, 0x0F, 0x0F, 0x09, 0x0F, 0x0F, 0x07, 0x00,
0x00, 0x0C, 0x0E, 0x0F, 0x03, 0x0F, 0x0E, 0x0C, 0x00, 0x00, 0x07, 0x0F, 0x0F, 0x08, 0x0F, 0x0F,
0x07, 0x00, 0x00, 0x03, 0x03, 0x03, 0x02, 0x0F, 0x0F, 0x0F, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0xFF, 0xFF, 0xFF,
0x07, 0x07, 0x07, 0x0F, 0x0E, 0x0E, 0x0E, 0x1E, 0x1C, 0x1C, 0x3C, 0x38, 0x38, 0x38, 0x78, 0x70,
0x70, 0xF0, 0xE0, 0xE0, 0xE0, 0xE0, 0xC0, 0xC0, 0xC0, 0x80, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03,
0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03,
0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03,
0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x03, 0x03, 0x03, 0x03, 0x07, 0x07, 0x07, 0x07,
0x0E, 0x0E, 0x0E, 0x1E, 0x1C, 0x1C, 0x1C, 0x38, 0x38, 0x38, 0x78, 0x70, 0x70, 0x70, 0xE0, 0xE0,
0xE0, 0xE0, 0xC0, 0xC0, 0xC0, 0x80, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0x80, 0x80,
0xC0, 0xC0, 0xC0, 0xE0, 0xE0, 0xE0, 0xE0, 0x70, 0x70, 0x70, 0x78, 0x38, 0x38, 0x38, 0x1C, 0x1C,
0x1C, 0x1F, 0x0F, 0x0F, 0x0F, 0x07, 0x07, 0x07, 0x07, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x03, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07,
0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07,
0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07,
0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xFF, 0xFF, 0xFF,
0x80, 0x80, 0x80, 0x80, 0xC0, 0xC0, 0xC0, 0xE0, 0xE0, 0xE0, 0xE0, 0x70, 0x70, 0x70, 0x78, 0x38,
0x38, 0x38, 0x1C, 0x1C, 0x1C, 0x1E, 0x0E, 0x0E, 0x0E, 0x07, 0x07, 0x07, 0x07, 0x03, 0x03, 0x03,
0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x07, 0x07,
0x07, 0x03, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00


};*/

/******************************************************************************/		
/* hard delay                                                                 */
/******************************************************************************/	
void Hard_Delay(unsigned int TIME)
{

    CNT_DELAY = 0;
    while (CNT_DELAY < TIME)
    {
        CLRWDT();
    }

}


/******************************************************************************/		
/* I2C ROUTINES                                                               */
/******************************************************************************/
/******************************************************************************/		
/* ekn na przdnej buffer SSPBUF I2C                                       */
/******************************************************************************/
void Wait_Until_Buffer_Empty(void)
{
	while (SSPSTATbits.RW == 1)
	{
	}
}


/******************************************************************************/		
/* ekn na dokonen ten I2C                                              */
/******************************************************************************/
void Wait_Until_Read_End(void)
{
	SSPCON2bits.RCEN = ACTIVE;
	while (SSPCON2bits.RCEN == ACTIVE)              // ek na ukonen S
	{
	}	
}

/******************************************************************************/		
/* start condition                                                            */
/******************************************************************************/	
void I2c_Start (void)
{
    SSPCON2bits.ACKDT = 0;
    SSPCON2bits.ACKEN = 1;

    SSPCON2bits.SEN = ACTIVE;		// generuje start conditions (S)
	while (SSPCON2bits.SEN == ACTIVE)	// ek na ukonen S
	{
		
	}	
}


/******************************************************************************/		
/* rstart condition                                                            */
/******************************************************************************/	
void I2c_Rstart (void)
{
    
    SSPCON2bits.RSEN = ACTIVE;		// generuje start conditions (S)
	while (SSPCON2bits.RSEN == ACTIVE)	// ek na ukonen S
	{
		
	}	
}

/******************************************************************************/		
/* stop condition                                                             */
/******************************************************************************/	
void I2c_Stop (void)
{
	SSPCON2bits.PEN = ACTIVE;					// generuje stop conditions (P)
	while (SSPCON2bits.PEN == ACTIVE)			// ek na ukonen P
	{
	
	}	
}

/******************************************************************************/		
/* acknowlege                                                                 */
/******************************************************************************/	
void I2c_ACK (void)
{
        SSPCON2bits.ACKDT = 0;
        SSPCON2bits.ACKEN = 1;
        while(SSPCON2bits.ACKEN == 1){};    
}


/******************************************************************************/		
/* NOTacknowlege                                                              */
/******************************************************************************/	
void I2c_NACK (void)
{
        SSPCON2bits.ACKDT = 1;
        SSPCON2bits.ACKEN = 1;
        while(SSPCON2bits.ACKEN == 1){};    
}

/******************************************************************************/		
/* zaopise data di I2C                                                        */
/******************************************************************************/	
void I2c_Write (unsigned char DATA)
{
    SSPBUF = DATA;  				// zapisovan data
	Wait_Until_Buffer_Empty();
}


//******************************************************************************
// I2C zapis 1 BYTE
//*****************************************************************************
I2C_Write_Byte(int ADDRESS, char DATA, unsigned char CHIP_ADR)
{
    I2c_Start();
    I2c_Write(CHIP_ADR);
    //I2c_Write(ADDRESS >> 8);
    I2c_Write(ADDRESS & 0x00ff);
    I2c_Write(DATA);
    I2c_Stop();
}

//******************************************************************************
// EEPROM zapis vce BYTE
//*****************************************************************************
I2C_Write_MByte(int ADDRESS, unsigned char CHIP_ADR)
{
    I2c_Start();
    I2c_Write(CHIP_ADR);
    //I2c_Write(ADDRESS >> 8);
    I2c_Write(ADDRESS & 0x00ff);
 
}

//******************************************************************************
// EEPROM cten 1 BYTE
//*****************************************************************************
unsigned char I2C_Read_Byte(int ADDRESS, unsigned char CHIP_ADR)
{
    unsigned char DATA;
    
    I2c_Start();
    I2c_Write(CHIP_ADR);
    I2c_Write(ADDRESS & 0x00ff);
    I2c_Rstart();
    I2c_Write(CHIP_ADR | 0b00000001);   
    
    Wait_Until_Read_End();
    
    
    I2c_Stop();
    
    DATA = SSPBUF;
}


//******************************************************************************
// EEPROM cten x BYTE
//*****************************************************************************
void I2C_Read_Page(unsigned char ADDRESS,char NUMBER, unsigned char CHIP_ADR)
{   
    char i;
    
    I2c_Start();
    I2c_Write(CHIP_ADR);
    //I2c_Write(ADDRESS >> 8);
    I2c_Write(ADDRESS);
    I2c_Rstart();
    I2c_Write(CHIP_ADR | 0b00000001); 
    
    
    
    for(i=0; i < NUMBER; i++)
    {              
        Wait_Until_Read_End(); 
        if(i < (NUMBER-1)) I2c_ACK(); //opakuje ACK pro dal ten  
        else I2c_NACK();              //posledn byte bez ACK
    
        I2C_BUFFER_1[i] = SSPBUF;
    } 
    
    I2c_Stop();
}



//******************************************************************************
// OLED ROUTINES
//*****************************************************************************

void OLED_command(unsigned char ind, unsigned char com)
{
   I2c_Start ();
   I2c_Write (ind);
   I2c_Write (0x00);
   I2c_Write (com);
   I2c_Stop ();
}

void OLED_write(unsigned char ind)
{
   unsigned int i;
 
   
   OLED_command (ind, 0x21);
   OLED_command (ind, 0x00);
   OLED_command (ind, 0x7F);
   OLED_command (ind, 0x22);
   OLED_command (ind, 0x00);
   OLED_command (ind, 0x07);
   I2c_Start ();
   I2c_Write (ind);
   I2c_Write (0x40);
   
   for (i = 0; i < 1024; i++)
   {           
      I2c_Write (DISPLAY[i]);   
   }

   I2c_Stop ();
   
}

void  OLED_init(unsigned char add)
{
   OLED_command (add, 0xae); //display OFF
   OLED_command (add, 0xa8); //multiplex ratio
   OLED_command (add, 0x3f); //*****
   OLED_command (add, 0xd3); //set display offset
   OLED_command (add, 0x00);//*****
   OLED_command (add, 0x40); // set start line 
   
   OLED_command (add, 0xa0); //set segment remap seg0-127
   OLED_command (add, 0xa1);
   
   OLED_command (add, 0xc0); //scan - normal
   OLED_command (add, 0xc8); //scan - mirror
   
   OLED_command (add, 0xda); //left right remap
   OLED_command (add, 0x12); //**for 128x64
   OLED_command (add, 0x81); //kontrast
   OLED_command (add, 0xFF); //***
   OLED_command (add, 0xa4); //
   OLED_command (add, 0xa6); //normal display A6, invert A7
   OLED_command (add, 0xd5); //oscilator frekvence
   OLED_command (add, 0x80); //*****
   OLED_command (add, 0x8d); //charge pump
   OLED_command (add, 0x14) ;
   
   OLED_command (add, 0xDB) ;
   OLED_command (add, 0x00) ;
   
   OLED_command (add, 0xAF) ; //display ON
   OLED_command (add, 0x20) ; //set adresing mode
   OLED_command (add, 0x00) ;
}

    void OLED_pixel(unsigned char x,unsigned char y)
    {
       
        unsigned int nt;
        unsigned int pagina;
        unsigned int bits;
    
        //********
    
        pagina  = y/8;        bits    = y-(pagina*8);
        nt      = DISPLAY[pagina*128+x];                   
        nt      |= 0x01 << bits;           
        DISPLAY[pagina*128+x] = nt;
   
}
    
//***************************************************************************
// ra
//***************************************************************************  
    void OLED_line (int x1, int y1, int x2, int y2)
    {
        int x, y, addx, addy, dx, dy;
        long P;
        int i;
        dx = abs ( (int) (x2 - x1));
        dy = abs ( (int) (y2 - y1));
        x = x1;
        y = y1;

        if (x1 > x2)
         addx = -1;

        else
        addx = 1;

        if (y1 > y2)
         addy = -1;

        else
        addy = 1;

        if (dx >= dy)
        {
            P = 2 * dy - dx;
            for (i = 0; i <= dx;  ++i)
            {
                OLED_pixel (x, y);

                if (P < 0)
                {
                    P += 2*dy;
                    x += addx;
                }

            else
            {
               P += 2*dy - 2 * dx;
               x += addx;
               y += addy;
            }
         }
      }

      else
      {
         P = 2 * dx - dy;
         for (i = 0; i <= dy;  ++i)
         {
            OLED_pixel (x, y);

            if (P < 0)
            {
               P += 2*dx;
               y += addy;
            }

            else
            {
               P += 2*dx - 2 * dy;
               x += addx;
               y += addy;
            }
         }
      }
    }

    
    
 //***************************************************************************
// kruh
//***************************************************************************    
    void OLED_circle(char x, char y, char radius, char riemp)
   {
      int a, b, P;
      a = 0;
      b = radius;
      P = 1 - radius;

      do
      {
         if (riemp)
         {
            OLED_line (x - a, y+b, x + a, y + b);
            OLED_line (x - a, y-b, x + a, y - b);
            OLED_line (x - b, y+a, x + b, y + a);
            OLED_line (x - b, y-a, x + b, y - a);
         }

         else
         {
            OLED_pixel (a + x, b+y);
            OLED_pixel (b + x, a+y);
            OLED_pixel (x - a, b+y);
            OLED_pixel (x - b, a+y);
            OLED_pixel (b + x, y-a);
            OLED_pixel (a + x, y-b);
            OLED_pixel (x - a, y-b);
            OLED_pixel (x - b, y-a);
         }

         if (P < 0)
            P += 3 + 2 * a++;

         else
         P += 5 + 2 * (a++ - b--);
      } while (a <= b);
   }

//***************************************************************************
// bit test
//***************************************************************************  
unsigned char  bit_test (unsigned char word, unsigned char n)  
{  
    
    if (n > 7) return 0;  
    if ((word & (0x01 << n))!=0) return 1;  
    else  return 0; 
        
}    
   
//***************************************************************************
// text
//***************************************************************************  
   void OLED_text(unsigned char x, unsigned char y, unsigned char* textptr, unsigned char size)
   {
          
      unsigned int I, J, K, L, M;       // Loop counters      
      unsigned char pixelData[5];       // Stores character data
      
      for (I = 0; textptr[I] != '\0'; ++I, ++x) // Loop through the passed string
      {
         // Checks if the letter is in the first text array 
         if (textptr[I] < 'S') memcpy (pixelData, TEXT[textptr[I] - ' '], 5);
         
         // Check if the letter is in the second array
         else if (textptr[I] <= '~') memcpy (pixelData, TEXT2[textptr[I] - 'S'], 5);
     
         // DEFAULT to space
         else memcpy (pixelData, TEXT[0], 5); // DEFAULT to space
        
         
         
         if (x + 5 * size >= 128)   // Performs character wrapping
         {
            x = 0;                  // Set x at far left position
            y += 7*size + 1;        // Set y at next position down
         }

         for (J = 0; J < 5; ++J, x += size)  // Loop through character byte data
         {
            for (K = 0; K < 7 * size; ++K)  // Loop through the vertical pixels
            {                  
               if (bit_test (pixelData[J], K)) // Check if the pixel should be set              
               {                  
                  for (L = 0; L < size; ++L) // The next two loops change the
                  {
                     // character's size
                     for (M = 0; M < size; ++M)
                     {
                        OLED_pixel (x + M, y+K * size + L); // Draws the pixel
                        
                     }
                  }
               }
            }
         }
      } 
   }

//***************************************************************************
// obdelnk
//***************************************************************************     
   void OLED_rect(int x1, int y1, int x2, int y2, int riemp)
   {
      if (riemp)
      {
         int y, ymax;      // Find the y min and max
         if (y1 < y2)
         {
            y = y1;
            ymax = y2;
         }

         else
         {
            y = y2;
            ymax = y1;
         }

         for (; y <= ymax; ++y)     // Draw lines to fill the rectangle
            OLED_line (x1, y, x2, y);
      }

      else
      {
         OLED_line (x1, y1, x2, y1); // Draw the 4 sides
         OLED_line (x1, y2, x2, y2);
         OLED_line (x1, y1, x1, y2);
         OLED_line (x2, y1, x2, y2);
      }
   }

   
//***************************************************************************
// clear display - V RAMCE
//***************************************************************************     
   void OLED_clear()
   {
      unsigned int x;
      for (x = 0; x < 1024; x++)
      {
         DISPLAY[x] = 0x00;
      }
   }   
   
   
//***************************************************************************
// uvodn logo
//***************************************************************************     
void logo()
{
      unsigned int x;
      unsigned char c;
 
      //bitmapa
     /* for (x = 0; x < 1024; x++)
      {
         c = spam[x];
         DISPLAY[x] = c;
      }*/
      
      for (x=0; x < 69; x++)
      { 
        
        x=x+2; //zrychlen pohybu  
        OLED_clear();  
        
        OLED_text(25,x,"ESSGIAS",2); 
        OLED_write(ind);      
        
        CLRWDT();
      }    
}


   
/******************************************************************************/
/* ten A/D pevodnku                                                       */
/******************************************************************************/
	
unsigned int Read_AD_Converter(unsigned char INPno)
{
	unsigned long	VALUE;
	unsigned char	i;	
	const char		PASS=5;		// poet men pro prmrovn

	ADCON0 = ADCON0 & 0b11000011;
	ADCON0 = ADCON0 | INPno;
	VALUE = 0;
	
	for (i=0 ; i < PASS; i++)	// prmrovn
	{
	GODONE = 1;
		while (GODONE != 0)
		{
		}
	VALUE = VALUE + ((ADRESH * 256) + ADRESL);
	}

	return VALUE/PASS;
}   
   
  
//***************************************************************************
// PWM SERVICE
//***************************************************************************     
void PWM_SERVICE()
{
   /*     if (SW_PLUS == OFF)
        {
        ++PWM_DUTY_FULL;
        PWM_DUTY_FULL = PWM_DUTY_FULL + 100;
        if (PWM_DUTY_FULL > 1023) PWM_DUTY_FULL = 1023; //Omezen9 max proudu solenoidu
        //while (SW_PLUS == OFF){};
        
        }
        if (SW_MINUS == OFF)
        {
        --PWM_DUTY_FULL;
        PWM_DUTY_FULL = PWM_DUTY_FULL - 100;    
        if (PWM_DUTY_FULL > 1023) PWM_DUTY_FULL = 0;
        //while (SW_MINUS == OFF){};
        }
     */   
                
        
        PWM_LB = PWM_DUTY_FULL & 0b0000000000000011;
        PWM_LB = PWM_LB << 4;
        PWM_MB = PWM_DUTY_FULL >> 2;
          
        CCP2CON = CCP2CON & 0b11001111;
        CCP2CON = CCP2CON | PWM_LB;
        CCPR2L  = PWM_MB;   
                
        CCP5CON = CCP5CON & 0b11001111;
        CCP5CON = CCP5CON | PWM_LB;
        CCPR5L  = PWM_MB;  
        
        PRESS_IN_PROGRES = ON;
               
}   


//******************************************************************************
// Inicializace LIS2DW12                                                       *
//******************************************************************************
void LIS2DW12_INIT(void)
{
    
    CNT_GENERAL = 0;
    while(CNT_GENERAL < 100){CLRWDT();} //wait 2 ms
    
    
    do{GENERAL_DATA = I2C_Read_Byte(0x0F, LIS2DW12_ADR);} //test komunikace vrat 0x1E
    while (GENERAL_DATA != 0x44);
   
   
    
    CNT_GENERAL = 0;
    while(CNT_GENERAL < 2){CLRWDT();} //wait 2 ms
    
    I2C_Write_Byte(0x20,0b10000101,LIS2DW12_ADR); //acc on
    
    CNT_GENERAL = 0;
    while(CNT_GENERAL < 100){CLRWDT();} //wait 100 ms
    
        
    I2C_Write_Byte(0x25,ACC_RANGE, LIS2DW12_ADR); //00-2g, 10-4g, 20-8g, 30-16g
   
}


//******************************************************************************
// te hodnoty acc z BMI270 nebo LIS2DW12                                                    *
//******************************************************************************
void Read_ACC_LIS2DW12(unsigned char REG_ADR, unsigned char CHIP_ADR, unsigned char RANGE)
{ 


    // te acc
        I2C_Read_Page(REG_ADR,6, CHIP_ADR ); //0x12 gyro, 0x0C acc
        
        ACC_X = (I2C_BUFFER_1[1]  << 8) + I2C_BUFFER_1[0];
        ACC_Y = (I2C_BUFFER_1[3]  << 8) + I2C_BUFFER_1[2];
        ACC_Z = (I2C_BUFFER_1[5]  << 8) + I2C_BUFFER_1[4];
        
       
        ACC_X_MG = ACC_X;
        ACC_Y_MG = ACC_Y;
        ACC_Z_MG = ACC_Z;
 
        
        if (RANGE == LIS2DW12_2G)   DIVIDER = 0.244;
        if (RANGE == LIS2DW12_4G)   DIVIDER = 0.488;
        if (RANGE == LIS2DW12_8G)   DIVIDER = 0.976;
        if (RANGE == LIS2DW12_16G)  DIVIDER = 1.952;
        
        
        
        ACC_X_MG = (ACC_X_MG/4) * DIVIDER;
        ACC_Y_MG = (ACC_Y_MG/4) * DIVIDER;
        ACC_Z_MG = (ACC_Z_MG/4) * DIVIDER;

     
        
        ACC_X = ACC_X_MG;
        ACC_Y = ACC_Y_MG;
        ACC_Z = ACC_Z_MG; 
    
}



//******************************************************************************
// te hodnoty teploty z LIS2DW12                                              *
//******************************************************************************
void Read_Temparature_LIS2DW12(unsigned char ADR)
{ 
        
    unsigned int TEMP_UINT11;
    
    I2C_Read_Page(ADR,2, LIS2DW12_ADR); 
    
    
   //I2C_BUFFER_1[0] = 0x80;
   //I2C_BUFFER_1[1] = 0xE8;
    
        
    TEMP_UINT11 = (I2C_BUFFER_1[0]) + (I2C_BUFFER_1[1]* 256);
 
   
    TEMP_DEC = I2C_BUFFER_1[0] * T;
    
    if ((I2C_BUFFER_1[1] & (0b10000000)) != 0)
    {
        TEMP_FL = 25 - (256 - I2C_BUFFER_1[1]);   
        TEMP_FL = TEMP_FL + TEMP_DEC;        
    }    
    else
    {    
        TEMP_FL = 25 + I2C_BUFFER_1[1];
        TEMP_FL = TEMP_FL + TEMP_DEC;
    }
    
    
    //TEMP_FL = round(TEMP_FL);
    //TEMP_FL_ABS = fabs(TEMP_FL);

    //TEMPERATURE = (char)TEMP_FL_ABS;
        
    TEMPERATURE = (char)TEMP_FL;    
    
    if (TEMP_FL < (0.0)) 
    {
        TEMPERATURE = TEMPERATURE + 0x80;
    }    
        
 
}


//******************************************************************************
// PRINT HODNOT NA UART - FLOAT                                                *
//******************************************************************************
void Print_Value_Float(float DATA_X,float DATA_Y,float DATA_Z, float DATA_T)
{        
      
        int status;
        char *text;  
    
       
        text=ftoa(DATA_X,&status);
        strcpy(ACC_X_STR,text);
        
        text=ftoa(DATA_Y,&status);
        strcpy(ACC_Y_STR,text);
        
        text=ftoa(DATA_Z,&status);
        strcpy(ACC_Z_STR,text);
        
        text=ftoa(DATA_T,&status);
        strcpy(ACC_T_STR,text);
        
}

//******************************************************************************
// formtovn zobrazen tlaku na displeji                              *
//******************************************************************************

void    Press_Format_Display(void)
{
             
        // zobraz tlak
    
        utoa(PRESS_STR,PRESS_1_KPA,10);
        GPD1 = strlen(PRESS_STR);
        
        TEMPR[0] = 'P';
        TEMPR[1] = 'R';
        TEMPR[2] = 'S';
        TEMPR[3] = ' ';
        TEMPR[4] = 'p';
        TEMPR[5] = '=';
        
        for(j=6; j < (GPD1+7);j++)
        {
            TEMPR[j] = PRESS_STR[j-6];
        }  
                        
        OLED_text(8,52,TEMPR,1);
        
        //zobraz pedvolbu tlaku        
        memset(TEMPR,0,10);                 //vynuluje TEMPR
        utoa(PRESS_STR,PRESS_IN_BOTTLE,10);
        GPD1 = strlen(PRESS_STR);
        
        TEMPR[0] = 'S';
        TEMPR[1] = 'E';
        TEMPR[2] = 'T';
        TEMPR[3] = '=';
        
        
        for(j=4; j < (GPD1+5);j++)
        {
            TEMPR[j] = PRESS_STR[j-4];
        }  
        
        TEMPR[j-1]  = 'k'; 
        TEMPR[j]    = 'p';         
        TEMPR[j+1]  = '\0';
        
        OLED_text(65,52,TEMPR,1);
        
        
        
        
        //zobraz pedvolbu hystereze tlaku        
        memset(TEMPR,0,10);                 //vynuluje TEMPR
        utoa(PRESS_STR,PRESS_HYSTERESE,10);
        GPD1 = strlen(PRESS_STR);
        
        TEMPR[0] = 'H';
        TEMPR[1] = 'Y';
        TEMPR[2] = 'S';
        TEMPR[3] = '=';
        
        
        for(j=4; j < (GPD1+5);j++)
        {
            TEMPR[j] = PRESS_STR[j-4];
        }  
        
        TEMPR[j-1]  = 'k'; 
        TEMPR[j]    = 'p';         
        TEMPR[j+1]  = '\0';
        
        OLED_text(65,43,TEMPR,1);
                
}


//******************************************************************************
// formtovn ACC pro zobrazen na disp displeji                              *
//******************************************************************************

void    ACC_Format_Display(unsigned char COOR)
{
    
                    
        if (COOR == 'X')
        {   
            GPD1    = strchr(ACC_X_STR,'.');
            GPD2    = &ACC_X_STR;
        }  
        
        if (COOR == 'Y')
        {   
            GPD1    = strchr(ACC_Y_STR,'.');
            GPD2    = &ACC_Y_STR;
        }  
        
        if (COOR == 'Z')
        {   
            GPD1    = strchr(ACC_Z_STR,'.');
            GPD2    = &ACC_Z_STR;
        }
        
        if (COOR == 'T')
        {   
            GPD1    = strchr(ACC_T_STR,'.');
            GPD2    = &ACC_T_STR;
        }  
        
      
        DOT_POS = GPD1-GPD2;
        
        
        for(i=0; i< (DOT_POS + 3); i++)
        {
            if (COOR == 'X') ACC_H_STR[i] = ACC_X_STR[i];
            if (COOR == 'Y') ACC_H_STR[i] = ACC_Y_STR[i];
            if (COOR == 'Z') ACC_H_STR[i] = ACC_Z_STR[i];
            if (COOR == 'T') ACC_H_STR[i] = ACC_T_STR[i];
        }    
        ACC_H_STR[i] = '\0';
        
        TEMPR[0] = 'A';
        TEMPR[1] = 'C';
        TEMPR[2] = 'C';
        TEMPR[3] = ' ';
        if (COOR == 'X') TEMPR[4] = 'X';
        if (COOR == 'Y') TEMPR[4] = 'Y';
        if (COOR == 'Z') TEMPR[4] = 'Z';
        if (COOR == 'T') TEMPR[4] = 'T';
        TEMPR[5] = '=';
        
        for(j=6; j< (i+7);j++)
        {
            TEMPR[j] = ACC_H_STR[j-6];
        }  
        
       
        if (COOR == 'X') OLED_text(8,6,TEMPR,1);
        if (COOR == 'Y') OLED_text(8,15,TEMPR,1);
        if (COOR == 'Z') OLED_text(8,24,TEMPR,1);
        if (COOR == 'T') OLED_text(8,33,TEMPR,1);

}


//******************************************************************************
// Hlavn program
//*****************************************************************************
void main(void)
{	
    
	InitPeripherals(); 
    Init_RS232_1(57600);
    
   
    TEPLOTA = 0;
    INTCON3bits.INT3IF = OFF; //smae peruen po PWER UP
    ENCODER_VALUE = 0;
    
    //PWM START
    PWM2_OUTPUT = OFF;
    PWM5_OUTPUT = OFF;    
    CCPR2L  = 0;
    CCPR5L  = 0;
    CCP2CON = CCP2CON & 0b11001111;
    CCP5CON = CCP5CON & 0b11001111;
    TMR2ON	= ACTIVE;
    TMR4ON	= ACTIVE;
    
    
    OLED_init(ind);
    OLED_clear(); 
    OLED_write(ind);
    
   
    logo();
    

    PWM_DUTY_FULL = 0;
    CNT_DELAY = 0;
    PRESS_IN_PROGRES = OFF;
    
    //inicializace LIS2DW12
    ACC_RANGE = LIS2DW12_16G;
    LIS2DW12_INIT();
    ACC_DISP_CNT = 0;
 
    DUTY_COMP1      = 0;
    DUTY_COMP2      = 0;
    MOTOR_RAMP_CNT  = 0;
    
    PRESS_IN_BOTTLE = 20;
    PRESS_HYSTERESE = 10;
    KOMPR_HIGH      = ON;
    PROCES_START    = OFF;
    VENTIL_DELAY    = 0;

    
   
/******************************************************************************/
/* HLAVN smyka 															  */
/******************************************************************************/
while (1)
{	

   
	if (INT_PTR_1 >= 4) Send_Message_To_USART_2();
    
    if (CNT_DELAY >= 100)
    {              
        CNT_DELAY = 0;
        
        //men tlak
        PRESS_1 = Read_AD_Converter(AIN0);
        PRESS_2 = Read_AD_Converter(AIN1); 
        
        PRESS_FLOAT = PRESS_1/PRS;
        PRESS_1_KPA = PRESS_FLOAT;
        
        PRESS_FLOAT = PRESS_2/PRS;
        PRESS_2_KPA = PRESS_FLOAT;
      
        
        
            
        OLED_clear();        
  
        GPD1 = PWM_DUTY_FULL/10;
        //GPD1 = DUTY_COMP1;
        utoa(PRESS_STR,GPD1,10); 
       
        TEMPR[0] = PRESS_STR[0];
        TEMPR[1] = PRESS_STR[1];
        TEMPR[2] = PRESS_STR[2];
        TEMPR[3] = PRESS_STR[3];
        TEMPR[4] = '\0';
        
        OLED_text(8,43,"PWM D=",1); 
        OLED_text(45,43,TEMPR,1); 
        
 
        
        //sprintf(ZNAKY,ZPRAVA);
        //OLED_text(10,0,ZNAKY,1); 
         

        
        Print_Value_Float(ACC_X_MG,ACC_Y_MG,ACC_Z_MG,TEMP_FL);
        ACC_Format_Display('X');
        ACC_Format_Display('Y');
        ACC_Format_Display('Z');
        ACC_Format_Display('T'); //teplota
        Press_Format_Display();
        
        
        
        //OLED_circle(83,19,3,0); //stupn celsia   
        //OLED_line(0,42,127,42);
       
        OLED_rect(0,0,127,63,0);
        OLED_write(ind);
  
    }
    
    
     //PWM SERVICE 
     if(PRESS_IN_PROGRES == OFF) PWM_SERVICE();
     if ((SW_PLUS == ON) && (SW_MINUS == ON)) PRESS_IN_PROGRES = OFF;
    
    
    
     //OBSLUHA LIS2DW12  ACC+TEPLOTA   
     if(ACC_DISP_CNT >= 500)
     {         
        ACC_DISP_CNT = 0;    
        
        do{GENERAL_DATA = I2C_Read_Byte(0x27,LIS2DW12_ADR);} //data acc ready?
        while ((GENERAL_DATA & 0b00000001) != 0x01);        
        Read_ACC_LIS2DW12(0x28,LIS2DW12_ADR,ACC_RANGE);
        
     
        do{GENERAL_DATA = I2C_Read_Byte(0x37,LIS2DW12_ADR);} //data teploty ready?
        while ((GENERAL_DATA & 0b01000000) != 0x40);        
        Read_Temparature_LIS2DW12(0x0D);             
     }
    
 
    
    
    //spoutn a vypnn tlakovn
    if ((SW_ENTER == OFF) && (PROCES_START == OFF))
    {
        PROCES_START    = ON;        
        while (SW_ENTER == OFF){};
    }    
    
    if ((SW_ENTER == OFF) && (PROCES_START == ON))
    {
        PROCES_START = OFF;
        VENTIL_DELAY = 0;
        while (SW_ENTER == OFF){};
    }    
    
    
    //regulace tlaku v lhvi ****************************
    
    if (PROCES_START == ON)
    {    
        if (PRESS_1_KPA < PRESS_IN_BOTTLE - PRESS_HYSTERESE)
        {
            DUTY_COMP1      = 80;    //napoutc
            DUTY_COMP2      = 0;     //vypoutc
            KOMPRESOR_RUN   = ON;   
            KOMPR_HIGH      = ON;        
        }
    
        if (PRESS_1_KPA >= PRESS_IN_BOTTLE)
        {
            DUTY_COMP1      = 0;     //napoutc
            DUTY_COMP2      = 75;    //vypoutn 72
            PWM_DUTY_FULL   = 0;  //motor kompresoru   
            KOMPRESOR_RUN   = OFF;        
        }
    
        if (KOMPRESOR_RUN == ON)    //snen rychlosti kompresoru
        {
            if(PRESS_1_KPA < (PRESS_IN_BOTTLE - 2))  //(PRESS_1_KPA < ((PRESS_IN_BOTTLE - 5) && (KOMPR_HIGH == ON))) 
            {
            if (KOMPR_HIGH == ON) PWM_DUTY_FULL = 990;    //motor 99%   
            }      
            else 
            {
            PWM_DUTY_FULL   = 700;    //motor 70%  
            KOMPR_HIGH      = OFF;
            }    
        }
        else PWM_DUTY_FULL = 0;
    } 
    else
    {
        DUTY_COMP1      = 0;     //napoutc
        if (VENTIL_DELAY < 6) DUTY_COMP2 = 90;    //vypoutn 90
        else DUTY_COMP2 = 0;
        PWM_DUTY_FULL   = 0;  //motor kompresoru   
        KOMPRESOR_RUN   = OFF;     
    }    
    
    
    //nastavovn hystereze tlaku
        if (SW_PLUS == OFF)
        {
            ++PRESS_HYSTERESE;        
            if (PRESS_HYSTERESE > 90) PRESS_HYSTERESE = 90; //Omezen9 max proudu solenoidu
            while (SW_PLUS == OFF){CLRWDT();};
        
        }
        if (SW_MINUS == OFF)
        {
            --PRESS_HYSTERESE;        
            if (PRESS_HYSTERESE < 1) PRESS_HYSTERESE = 1;
            while (SW_MINUS == OFF){CLRWDT();};
        }
    
   
    
	CLRWDT();
}


}